@@ -16,7 +16,6 @@
 */
 
 #include <gtest/gtest.h>
-#include <boost/filesystem.hpp>
 #include <boost/any.hpp>
 #include <ignition/math.hh>
 #include "test_config.h"
@@ -28,32 +27,11 @@ class SDFUpdate : public testing::Test
 {
   protected: SDFUpdate()
              {
-               boost::filesystem::path path =
-                 boost::filesystem::path(PROJECT_SOURCE_PATH)
-                 / "sdf" / SDF_VERSION;
-
-               // Store original env var.
-#ifndef _WIN32
-               this->origSDFPath = getenv("SDF_PATH");
-#else
-               this->origSDFPath = const_cast<char*>(
-                   sdf::winGetEnv("SDF_PATH"));
-#endif
-
-               setenv("SDF_PATH", path.string().c_str(), 1);
              }
 
   protected: virtual ~SDFUpdate()
              {
-               // Restore original env var.
-               // osx segfaults unless this check is in place
-               // some discussion of portability of setenv at:
-               // http://www.greenend.org.uk/rjk/tech/putenv.html
-               if (this->origSDFPath)
-                 setenv("SDF_PATH", this->origSDFPath, 1);
              }
-
-  private: char *origSDFPath;
 };
 
 class SDFUpdateFixture
